==> adc-lib-v2.3.0.tar: adc-lib-v2.3.0/lib/adc-ziofake.c <==
#define _GNU_SOURCE
#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/types.h>
#include <poll.h>
#include <sys/stat.h>

#include <linux/zio-user.h>

#include "adc-lib.h"
#include "adc-lib-int.h"

#define FAKE_ZIO_DEV_PATH "/dev/zio"
#define FAKE_ZIO_SYS_PATH "/sys/bus/zio/devices"


static struct adc_dev *adc_ziofake_open(const struct adc_board_type *b,
					unsigned int dev_id,
					unsigned long totalsamples,
					unsigned int nbuffer,
					unsigned long flags)
{
	struct adc_dev *dev = adc_zio_open(b, dev_id, totalsamples,
					   nbuffer, flags);
	struct __adc_dev_zio *fk = to_dev_zio(dev);

	fk->samplesize = 1; /* FIXME: should read sysfs instead -- where? */
	dev = (void *) &fk->gid;

	return dev;
}

static int adc_ziofake_acq_start(struct adc_dev *dev, unsigned int flags,
				 struct timeval *timeout)
{
	if (flags & ADC_F_FLUSH) {
		int err = adc_acq_flush(dev, ADC_FLUSH_F_ANY);
		if (err)
			return err;
	}

	if (timeout && timeout->tv_sec == 0 && timeout->tv_usec == 0)
		return 0;

	return adc_acq_poll(dev, 0, timeout);
}

static int adc_ziofake_acq_stop(struct adc_dev *dev, unsigned int flags)
{
	return 0;
}

static int adc_ziofake_acq_flush(struct adc_dev *dev, unsigned int flags)
{
	return adc_zio_acq_flush(dev, flags);
}


static int adc_ziofake_buffer_get_sample(struct adc_buffer *buf,
					 unsigned int chan,
					 unsigned int acq_sample,
					 int32_t *value)
{
	if (chan >= 1) {
		errno = EINVAL;
		return -1;
	}

	*value = ((int8_t *)buf->data)[acq_sample];

	return 0;
}

#define ADC_ZIO_ACQ_MASK (1LL << ADC_CONF_ACQ_N_SHOTS) | \
			 (1LL << ADC_CONF_ACQ_POST_SAMP) | \
			 (1LL << ADC_CONF_ACQ_PRE_SAMP) | \
			 (1LL << ADC_CONF_ACQ_N_BITS)
#define ADC_ZIO_CHN_MASK (1LL << ADC_CONF_CHN_OFFSET) | \
			 (1LL << ADC_CONF_CHN_GAIN)
#define ADC_ZIO_BRD_MASK (1LL << ADC_CONF_BRD_N_CHAN)


static struct adc_operations fa_zio_fake_op = {
	.open = 		adc_ziofake_open,
	.close =		adc_zio_close,

	.acq_start =		adc_ziofake_acq_start,
	.acq_poll =		adc_zio_acq_poll,
	.acq_stop =		adc_ziofake_acq_stop,
	.acq_flush =		adc_ziofake_acq_flush,

	.apply_config = 	adc_zio_apply_config,
	.retrieve_config =	adc_zio_retrieve_config,

	.get_param =		adc_zio_get_param,
	.set_param =		adc_zio_set_param,

	.request_buffer =	adc_zio_request_buffer,
	.fill_buffer =		adc_zio_fill_buffer,
	.tstamp_buffer =	adc_zio_tstamp_buffer,
	.release_buffer =	adc_zio_release_buffer,
	.buffer_get_sample =	adc_ziofake_buffer_get_sample,
};

struct adc_board_type adc_ziofake = {
	.name = ADC_NAME_ZIOFAKE,
	.devname = "zzero",
	.driver_type = "zio",
	.capabilities = {
		[ADC_CONF_TYPE_BRD] = ADC_ZIO_BRD_MASK,
		[ADC_CONF_TYPE_CHN] = ADC_ZIO_CHN_MASK,
		[ADC_CONF_TYPE_ACQ] = ADC_ZIO_ACQ_MASK,
		[ADC_CONF_TYPE_TRG_EXT] = 0x0,
		[ADC_CONF_TYPE_TRG_THR] = 0x0,
		[ADC_CONF_TYPE_TRG_TIM] = 0x0,
	},
	.adc_op = &fa_zio_fake_op,
};

==> adc-lib-v2.6.0.tar: adc-lib-v2.6.0/lib/adc-ziofake.c <==
#define _GNU_SOURCE
#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/types.h>
#include <poll.h>
#include <sys/stat.h>

#include <linux/zio-user.h>

#include "adc-lib.h"
#include "adc-lib-int.h"

#define FAKE_ZIO_DEV_PATH "/dev/zio"
#define FAKE_ZIO_SYS_PATH "/sys/bus/zio/devices"


static struct adc_dev *adc_ziofake_open(const struct adc_board_type *b,
					unsigned int dev_id,
					unsigned long totalsamples,
					unsigned int nbuffer,
					unsigned long flags)
{
	struct adc_dev *dev = adc_zio_open(b, dev_id, 0, 0, totalsamples,
					   nbuffer, flags);
	struct __adc_dev_zio *fk = to_dev_zio(dev);

	fk->samplesize = 1; /* FIXME: should read sysfs instead -- where? */
	dev = (void *) &fk->gid;

	return dev;
}

static int adc_ziofake_acq_start(struct adc_dev *dev, unsigned int flags,
				 struct timeval *timeout)
{
	if (flags & ADC_F_FLUSH) {
		int err = adc_acq_flush(dev, ADC_FLUSH_F_ANY);
		if (err)
			return err;
	}

	if (timeout && timeout->tv_sec == 0 && timeout->tv_usec == 0)
		return 0;

	return adc_acq_poll(dev, 0, timeout);
}

static int adc_ziofake_acq_stop(struct adc_dev *dev, unsigned int flags)
{
	return 0;
}

static int adc_ziofake_acq_flush(struct adc_dev *dev, unsigned int flags)
{
	return adc_zio_acq_flush(dev, flags);
}


static int adc_ziofake_buffer_get_sample(struct adc_buffer *buf,
					 unsigned int chan,
					 unsigned int acq_sample,
					 int32_t *value)
{
	if (chan >= 1) {
		errno = EINVAL;
		return -1;
	}

	*value = ((int8_t *)buf->data)[acq_sample];

	return 0;
}

#define ADC_ZIO_ACQ_MASK (1LL << ADC_CONF_ACQ_N_SHOTS) | \
			 (1LL << ADC_CONF_ACQ_POST_SAMP) | \
			 (1LL << ADC_CONF_ACQ_PRE_SAMP) | \
			 (1LL << ADC_CONF_ACQ_N_BITS)
#define ADC_ZIO_CHN_MASK (1LL << ADC_CONF_CHN_OFFSET) | \
			 (1LL << ADC_CONF_CHN_GAIN)
#define ADC_ZIO_BRD_MASK (1LL << ADC_CONF_BRD_N_CHAN)


static struct adc_operations fa_zio_fake_op = {
	.open = 		adc_ziofake_open,
	.close =		adc_zio_close,

	.acq_start =		adc_ziofake_acq_start,
	.acq_poll =		adc_zio_acq_poll,
	.acq_stop =		adc_ziofake_acq_stop,
	.acq_flush =		adc_ziofake_acq_flush,

	.apply_config = 	adc_zio_apply_config,
	.retrieve_config =	adc_zio_retrieve_config,

	.get_param =		adc_zio_get_param,
	.set_param =		adc_zio_set_param,

	.request_buffer =	adc_zio_request_buffer,
	.fill_buffer =		adc_zio_fill_buffer,
	.tstamp_buffer =	adc_zio_tstamp_buffer,
	.release_buffer =	adc_zio_release_buffer,
	.buffer_get_sample =	adc_ziofake_buffer_get_sample,
};

struct adc_board_type adc_ziofake = {
	.name = ADC_NAME_ZIOFAKE,
	.devname = "zzero",
	.driver_type = "zio",
	.capabilities = {
		[ADC_CONF_TYPE_BRD] = ADC_ZIO_BRD_MASK,
		[ADC_CONF_TYPE_CHN] = ADC_ZIO_CHN_MASK,
		[ADC_CONF_TYPE_ACQ] = ADC_ZIO_ACQ_MASK,
		[ADC_CONF_TYPE_TRG_EXT] = 0x0,
		[ADC_CONF_TYPE_TRG_THR] = 0x0,
		[ADC_CONF_TYPE_TRG_TIM] = 0x0,
	},
	.adc_op = &fa_zio_fake_op,
};
